@@ -1,18 +1,24 @@
-from captcha.fields import ReCaptchaField
-from crispy_forms.helper import FormHelper
-from crispy_forms.layout import Layout, Submit
-from django.conf import settings
 from django.forms import ModelForm, Textarea
 
+from captcha.fields import ReCaptchaField
+from captcha.widgets import ReCaptchaV2Invisible
+from crispy_forms.helper import FormHelper
+from crispy_forms.layout import Layout, Submit
+from csp_helpers.mixins import CSPFormMixin
+
+from . import settings as app_settings
 from .models import Comment
 
 
-class CommentForm(ModelForm):
-    if settings.RECAPTCHA_ENABLED:
-        captcha = ReCaptchaField()
+class CommentForm(CSPFormMixin, ModelForm):
+    if app_settings.RECAPTCHA_ENABLED:
+        if app_settings.RECAPTCHA_INVISIBLE:
+            captcha = ReCaptchaField(widget=ReCaptchaV2Invisible)
+        else:
+            captcha = ReCaptchaField()
 
     def __init__(self, *args, **kwargs):
-        super(CommentForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.helper = FormHelper()
         self.helper.form_show_labels = False
         self.helper.form_tag = False
@@ -22,8 +28,8 @@ class CommentForm(ModelForm):
 
         self.helper.layout = Layout(
             'text',
-            'captcha',
-            Submit('submit', 'Post Comment')
+            'captcha' if app_settings.RECAPTCHA_ENABLED else None,
+            Submit('Post Comment', 'Post Comment')
         )
 
     class Meta:
